## The RPM macro for the linker flags does not exist on EPEL
%if 0%{?epel} < 7
%{!?__global_ldflags: %global __global_ldflags -Wl,-z,relro}
%endif

%global with_check 1

Name:           gecode
Version:        4.4.0
Release:        12%{?dist}
Summary:        Generic constraint development environment

Group:          System Environment/Libraries
License:        MIT
URL:            http://www.gecode.org/
Source0:        http://www.gecode.org/download/%{name}-%{version}.tar.gz
Patch0:         gecode-4.0.0-no_examples.patch
Patch1:         gecode-4.4.0-gcc6.patch

BuildRequires:  automake
BuildRequires:  bison
%if 0%{?rhel}
BuildRequires:  boost148-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  flex >= 2.5.33
BuildRequires:  graphviz
BuildRequires:  qt4-devel

# for documentation
BuildRequires:  doxygen tex(latex) tex(dvips)

%description
Gecode is a toolkit for developing constraint-based systems and
applications. Gecode provides a constraint solver with state-of-the-art
performance while being modular and extensible.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package doc
Summary:        Documentation for %{name}
Group:          Documentation
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files for %{name}.

%package examples
Summary:        Example code for %{name}
Group:          Documentation
BuildArch: noarch

%description examples
The %{name}-examples package contains example code for %{name}.

%prep
%setup -q
%patch0 -p1 -b .no_examples
%if 0%{?fedora} > 23
%patch1 -p1 -b .gcc6
%endif

# Fix permissions
find . -name '*.hh' -exec chmod 0644 '{}' \;
find . -name '*.hpp' -exec chmod 0644 '{}' \;
find . -name '*.cpp' -exec chmod 0644 '{}' \;
chmod 0644 LICENSE misc/doxygen/*.png

# Fix encoding
pushd examples
for file in bin-packing.cpp black-hole.cpp dominating-queens.cpp scowl.hpp word-square.cpp; do
    iconv -f ISO-8859-1 -t UTF-8 -o $file.new $file && \
    touch -r $file $file.new && \
    mv $file.new $file
done
popd

# Remove default flags
sed -e 's|-ggdb||g' -i configure gecode.m4
sed -e 's|-O3||g' -i configure gecode.m4
sed -e 's|-fvisibility=hidden||g' -i configure gecode.m4

%build
%if 0%{?fedora} || 0%{?rhel} >= 7
autoreconf -ivf
%endif

%if 0%{?rhel} && 0%{?rhel} < 7
export CXXFLAGS="%{optflags} -Wl,-z,relro -fPIC -pie -Wl,-z,now -std=gnu++0x"
export CPPFLAGS=" -std=gnu++0x"
export LDFLAGS="%{__global_ldflags} -fPIC -pie -Wl,-z,now -lpthread"
%else
export CXXFLAGS="%{optflags}"
export LDFLAGS="%{__global_ldflags} -fPIC"
%endif
%configure \
 --disable-examples \
 --enable-float-vars \
 --enable-leak-debug \
%if 0%{?rhel}
 --with-boost-include=%{_includedir}/boost148
%else
 --with-boost-include=%{_includedir}/boost
%endif

make %{?_smp_mflags}
make doc
make ChangeLog

iconv --from=ISO-8859-1 --to=UTF-8 -o ChangeLog.new ChangeLog
mv ChangeLog.new ChangeLog

%install
make install DESTDIR=$RPM_BUILD_ROOT

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%if 0%{?with_check}
%check
make test
export LD_LIBRARY_PATH=$RPM_BUILD_ROOT%{_libdir}:%{_libdir}
make check
%endif

%files
%{!?_licensedir:%global license %doc}
%doc ChangeLog
%license LICENSE
%{_libdir}/*.so.*

%files devel
%{_bindir}/fzn-gecode
%{_bindir}/mzn-gecode
%{_datadir}/%{name}
%{_includedir}/%{name}
%{_libdir}/*.so

%files doc
%{!?_licensedir:%global license %doc}
%doc doc/html ChangeLog
%license LICENSE

%files examples
%{!?_licensedir:%global license %doc}
%doc examples/*
%license LICENSE

%changelog
* Mon May 30 2016 Julian Dunn <jdunn@aquezada.com> - 4.4.0-12
- Do not apply the bz#1334212 patch unless on GCC >= 6.x

* Sun May 29 2016 Julian Dunn <jdunn@aquezada.com> - 4.4.0-11
- Rebuilt for EPEL6
- Download targz source archive
- Using cmake to configure
- Set compiler flags
- Tests performed
- Built against Boost-1.48 on EPEL

* Wed May 25 2016 Than Ngo <than@redhat.com> - 4.4.0-10
- fix typo

* Tue May 17 2016 Than Ngo <than@redhat.com> - 4.4.0-9
- add better fix for bz#1334212

* Fri May 13 2016 Than Ngo <than@redhat.com> - 4.4.0-8
- fix bz#1334212, narrowing conversion
- cleanup

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 4.4.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jan 15 2016 Jonathan Wakely <jwakely@redhat.com> - 4.4.0-6
- Rebuilt for Boost 1.60

* Thu Aug 27 2015 Jonathan Wakely <jwakely@redhat.com> - 4.4.0-5
- Rebuilt for Boost 1.59

* Wed Jul 29 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.4.0-4
- Rebuilt for https://fedoraproject.org/wiki/Changes/F23Boost159

* Wed Jul 22 2015 David Tardon <dtardon@redhat.com> - 4.4.0-3
- rebuild for Boost 1.58

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.4.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 4.3.3-3
- Rebuilt for GCC 5 C++11 ABI change

* Mon Jan 26 2015 Petr Machata <pmachata@redhat.com> - 4.3.3-2
- Rebuild for boost 1.57.0

* Fri Jan 23 2015 Julian C. Dunn <jdunn@aquezada.com> - 4.3.3-1
- Update to 4.3.3

* Mon Sep 29 2014 Julian C. Dunn <jdunn@aquezada.com> - 4.3.0-1
- Update to 4.3.0

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.2.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.2.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 23 2014 Petr Machata <pmachata@redhat.com> - 4.2.1-2
- Rebuild for boost 1.55.0

* Sat Nov 16 2013 Julian C. Dunn <jdunn@aquezada.com> 4.2.1-1
- Update to 4.2.1

* Fri Aug 23 2013 Julian C. Dunn <jdunn@aquezada.com> 4.2.0-1
- Update to 4.2.0
- Switch to unversioned docdir for >= F20 (bz#993768)

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 4.0.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Jul 30 2013 Petr Machata <pmachata@redhat.com> - 4.0.0-2
- Rebuild for boost 1.54.0

* Sat Jun 15 2013 Julian C. Dunn <jdunn@aquezada.com> 4.0.0-1
- Update to 4.0.0

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.7.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Aug 23 2012 Julian C. Dunn <jdunn@aquezada.com> 3.7.3-3
- Fix build on EPEL6

* Tue Aug 21 2012 Julian C. Dunn <jdunn@aquezada.com> 3.7.3-2
- Post-review comments in bz#843695

* Sun May 20 2012 Julian C. Dunn <jdunn@aquezada.com> 3.7.3-1
- Update for 3.7.3
- Drop support for EPEL5. flex is too old

* Fri Apr 01 2011 Erik Sabowski and James Sulinski <team@aegisco.com> 3.5.0-1
- Update for gecode-3.5.0
- Disabled "gist" and "qt" configure options

* Sat May  8 2010 ELMORABITY Mohamed <melmorabity@fedoraproject.org> 3.3.1-1
- Initial RPM release
